timeseries.Signal.feature — GDA Toolbox v1.0 Manual

- GDA Toolbox v1.0 Manual
- Time-Series Data
- timeseries.Signal

- index
- modules
- next
- previous

# timeseries.Signal.feature

`Signal.` `feature`(index=None)

  return the region of a feature, with vertical displacement threshold tau.

#### Previous topic

timeseries.Signal

#### Next topic

timeseries.Signal.feature_match

- © Copyright 2015-2017, Geometric Data Analytics, Inc.
- Last updated on Jan 07, 2019.
- Created using Sphinx 1.8.2.